==> kadu_0.6.5.1.orig.tar.gz: kadu/modules/history/translations/history_en.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>@default</name>
    <message>
        <source>Chat</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>History</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>General</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save messages in history</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Status changes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show status changes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show status changes in history</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save status changes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save status changes in history</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Citation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Message citation in chat window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Don&apos;t cite messages older than</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>View history</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HistoryDialog</name>
    <message>
        <source>History</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Uins</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show status changes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Find &amp;next</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Find &amp;previous</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Online</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Busy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invisible</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Offline</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HistoryManager</name>
    <message>
        <source>Clear history?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Yes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HistoryModule</name>
    <message>
        <source>Show history</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear history</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 day(s) %2 hour(s)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The following users were deleted:
%0Do you want to remove history as well?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HistorySearchDialog</name>
    <message>
        <source>Search history</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;From:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>day</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>month</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>year</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>hour</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>minute</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Find Criteria</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Pattern</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Status</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pattern</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Status</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Reverse find</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reset</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> kadu_0.6.5.3.orig.tar.gz: kadu/modules/history/translations/history_en.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>@default</name>
    <message>
        <source>Chat</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>History</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>General</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save messages in history</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Status changes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show status changes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show status changes in history</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save status changes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save status changes in history</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Citation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Message citation in chat window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Don&apos;t cite messages older than</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>View history</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HistoryDialog</name>
    <message>
        <source>History</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Uins</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show status changes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Find &amp;next</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Find &amp;previous</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Online</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Busy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invisible</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Offline</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear history</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rebuild index</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HistoryManager</name>
    <message>
        <source>Clear history?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Yes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error opening history file </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error opening sms history file </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error opening new history file </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error opening new sms history file </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HistoryModule</name>
    <message>
        <source>Show history</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear history</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 day(s) %2 hour(s)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The following users were deleted:
%0Do you want to remove history as well?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HistorySearchDialog</name>
    <message>
        <source>Search history</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;From:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>day</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>month</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>year</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>hour</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>minute</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Find Criteria</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Pattern</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Status</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pattern</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Status</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Reverse find</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reset</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
